==> xemacs21-packages_2005.03.07.orig.tar.gz: xemacs21-packages-2005.03.07.orig/xemacs-packages/xwem/lisp/xwem-compat.el <==
;;; xwem-compat.el --- GNU Emacs compatibility layer.

;; Copyright (C) 2003 by Free Software Foundation, Inc.

;; Author: Zajcev Evgeny <zevlg@yandex.ru>
;; Created: Fri Dec 12 15:51:10 MSK 2003
;; Keywords: xwem, xlib
;; X-CVS: $Id: xwem-compat.el,v 1.6 2005/01/01 04:42:52 youngs Exp $

;; This file is part of XWEM.

;; XWEM is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; XWEM is distributed in the hope that it will be useful, but WITHOUT
;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
;; or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
;; License for more details.

;; You should have received a copy of the GNU General Public License
;; along with XEmacs; see the file COPYING.  If not, write to the Free
;; Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
;; 02111-1307, USA.

;;; Synched up with: Not in FSF

;;; Commentary:

;; Compatibility layer betwean XEmacs and GNU Emacs.  However xwem
;; still can't run on GNU Emacs.

;;; Code:


(defvar xwem-gnuemacs-p (string-match "GNU Emacs" emacs-version)
  "Non-nil when running under GNU Emacs.")

(defun xwem-define-prefix-command (name &optional mapvar)
  "Compat version for `define-prefix-command'."
  (if xwem-gnuemacs-p
      (define-prefix-command name)
    (define-prefix-command name t)))

(unless (fboundp 'set-keymap-default-binding)
  (fset 'set-keymap-default-binding
	(lambda (keym cmd) (define-key keym [t] cmd))))

(unless (fboundp 'events-to-keys)
  (defalias 'events-to-keys 'identity))


(provide 'xwem-compat)

;;; xwem-compat.el ends here

==> xemacs21-packages_2009.02.17.orig.tar.gz: xemacs21-packages-2009.02.17/xemacs-packages/xwem/lisp/xwem-compat.el <==
;;; xwem-compat.el --- GNU Emacs compatibility layer.

;; Copyright (C) 2003-2005 by XWEM Org.

;; Author: Zajcev Evgeny <zevlg@yandex.ru>
;; Created: Fri Dec 12 15:51:10 MSK 2003
;; Keywords: xwem, xlib
;; X-CVS: $Id: xwem-compat.el,v 1.4 2004/11/29 20:41:47 lg Exp $

;; This file is part of XWEM.

;; XWEM is free software; you can redistribute it and/or modify it
;; under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2, or (at your option)
;; any later version.

;; XWEM is distributed in the hope that it will be useful, but WITHOUT
;; ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
;; or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
;; License for more details.

;; You should have received a copy of the GNU General Public License
;; along with XEmacs; see the file COPYING.  If not, write to the Free
;; Software Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
;; 02111-1307, USA.

;;; Synched up with: Not in FSF

;;; Commentary:

;; Compatibility layer betwean XEmacs and GNU Emacs.  However xwem
;; still can't run on GNU Emacs.

;;; Code:


(defvar xwem-gnuemacs-p (string-match "GNU Emacs" emacs-version)
  "Non-nil when running under GNU Emacs.")

(defun xwem-define-prefix-command (name &optional mapvar)
  "Compat version for `define-prefix-command'."
  (if xwem-gnuemacs-p
      (define-prefix-command name)
    (define-prefix-command name t)))

(unless (fboundp 'set-keymap-default-binding)
  (fset 'set-keymap-default-binding
	#'(lambda (keym cmd) (define-key keym [t] cmd))))

(unless (fboundp 'events-to-keys)
  (defalias 'events-to-keys 'identity))


(provide 'xwem-compat)

;;; xwem-compat.el ends here
